Attribute

Enum Attribute 

pub enum Attribute {
    BadArchAction(Action),
    NoNewPrivileges(bool),
    ThreadSync(bool),
    NegativeSyscalls(bool),
    Log(bool),
    DisableSSB(bool),
    Optimize(OptimizeStrategy),
    ReturnSystemReturnCodes(bool),
}
Attributes.

Variants



BadArchAction(Action)

The action for when an invalid architecture is detected.



NoNewPrivileges(bool)

Deny new privileges on load



ThreadSync(bool)

Sync all threads in the process to make sure the filter applies.



NegativeSyscalls(bool)

Allow negative Syscalls.



Log(bool)

Log syscalls to Audit.



DisableSSB(bool)

Disable SSB Mitigation.



Optimize(OptimizeStrategy)

How the rules are ordered.



ReturnSystemReturnCodes(bool)

Return system return codes.

Implementations

Source

impl Attribute

pub fn name(&self) -> scmp_filter_attr

Get the raw name of the attribute.

pub fn value(&self) -> u32

Get the current value of the attribute.

pub fn str(&self) -> &'static str

Get a string value for the attribute