pub enum Attribute {
BadArchAction(Action),
NoNewPrivileges(bool),
ThreadSync(bool),
NegativeSyscalls(bool),
Log(bool),
DisableSSB(bool),
Optimize(OptimizeStrategy),
ReturnSystemReturnCodes(bool),
}Expand description
Attributes.
Variants
BadArchAction(Action)
The action for when an invalid architecture is detected.
NoNewPrivileges(bool)
Deny new privileges on load
ThreadSync(bool)
Sync all threads in the process to make sure the filter applies.
NegativeSyscalls(bool)
Allow negative Syscalls.
Log(bool)
Log syscalls to Audit.
DisableSSB(bool)
Disable SSB Mitigation.
Optimize(OptimizeStrategy)
How the rules are ordered.
ReturnSystemReturnCodes(bool)
Return system return codes.
Implementations